<p align="center">
  <a href="https://www.codeforlife.education/play/kurono/" target="_blank">
    <img src="/docs/images/kurono_logo_simple.svg" height="100px" alt="Kurono Logo" />
  </a>
</p>

<h3 align="center">
  Using intermediate Python, join your class on a time travelling adventure. Work together to complete challenges and unlock new time periods.
</h3>

[![Code Climate](https://codeclimate.com/github/ocadotechnology/aimmo/badges/gpa.svg)](https://codeclimate.com/github/ocadotechnology/aimmo)
[![codecov](https://codecov.io/gh/ocadotechnology/aimmo/branch/master/graph/badge.svg)](https://codecov.io/gh/ocadotechnology/aimmo)
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=flat-square)](http://makeapullrequest.com)
[![Zenhub Shield](https://camo.githubusercontent.com/96347b1f6d9b0f08194ba026de8b69bc27bb8f0d/68747470733a2f2f696d672e736869656c64732e696f2f62616467652f5368697070696e675f6661737465725f776974682d5a656e4875622d3565363062612e7376673f7374796c653d666c61742d737175617265)](https://app.zenhub.com/workspace/o/ocadotechnology/codeforlife-deploy-appengine/boards?repos=96999382,39072690)

<p align="center">
  <a href="https://www.codeforlife.education/play/kurono/" target="_blank">
      <img src="/docs/images/kurono_game.png" height="400px" alt="Kurono Game" />
  </a>
</p>

It is the year 3000 and the museum is in big trouble! The priceless artifacts are lost and scattered across timelines. Your team’s mission is to travel through time and bring them back into the museum.

## Quick Start
1. **Fork** the repo.
2. Take a look at our [usage guidelines](docs/usage.md) to see how to get started.

## Documentation
Take a look at our [documentation table of contents](docs/README.md).

## How to contribute!
__Want to help?__ You can read the [contributing guidelines][contrib-guidelines]. You can also contact us directly using this [contact form][c4l-contact-form] and we'll get in touch as soon as possible! Thanks a lot.

[c4l-contact-form]: https://www.codeforlife.education/help/#contact
[contrib-guidelines]: https://github.com/ocadotechnology/aimmo/blob/master/CONTRIBUTING.md
